@@ -1,3 +1,30 @@
+#' Capabilities
+#'
+#' A qualitative dataset of sample capabilities and qualitative level of effectiveness.
+#'
+#' \describe{
+#'   \item{id}{unique id of the capability}
+#'   \item{domain_id}{domain id to which the capability applies}
+#'   \item{capability}{full text summary of the capability}
+#'   \item{diff}{qualitative label of control effectiveness}
+#' }
+"capabilities"
+
+#' Qualitative to quantitative mappings
+#'
+#' A dataset of sample mappings from qualitative labels to quantitative
+#' distribution parameters.
+#'
+#' \describe{
+#'   \item{type}{OpenFAIR taxonomy to which this mapping applies}
+#'   \item{label}{Qualitative label}
+#'   \item{l}{BetaPERT low value}
+#'   \item{ml}{BetaPERT most likely value}
+#'   \item{h}{BetaPERT high value}
+#'   \item{conf}{BetaPERT confidence value}
+#' }
+"mappings"
+
 #' Domain mappings
 #'
 #' A dataset of domains and domain IDs.
@@ -14,9 +41,9 @@
 #' domain level.
 #'
 #' \describe{
-#'   \item{ale}{annual loss expected, in US dollars}
-#'   \item{domain}{full title of the domain}
 #'   \item{domain_id}{abbreviated name of the domain}
+#'   \item{domain}{full title of the domain}
+#'   \item{ale}{annual loss expected, in US dollars}
 #'   \item{simulation}{simulation id number}
 #' }
 "domain_summary"
@@ -27,28 +54,28 @@
 #' scenario level.
 #'
 #' \describe{
-#'   \item{ale_max}{maximum annual loss expected}
-#'   \item{ale_median}{median annual loss expected}
-#'   \item{ale_var}{value at risk, ale}
-#'   \item{ale_var_zscore}{Z-score of ale VaR}
 #'   \item{domain_id}{domain id}
-#'   \item{loss_events_max}{maximum number of loss events}
-#'   \item{loss_events_mean}{mean number of loss events}
-#'   \item{loss_events_median}{median number of loss events}
-#'   \item{loss_events_min}{minimum number of loss events}
-#'   \item{mean_diff_exceedance}{mean difficulty exceedance}
-#'   \item{mean_tc_exceedance}{mean threat capability exceedance}
-#'   \item{mean_vuln}{mean vulnerability of the scenario}
-#'   \item{outlier}{is this scenario an outlier}
 #'   \item{scenario_id}{ID of the scenario}
-#'   \item{sle_max}{single loss expectance max}
-#'   \item{sle_mean}{mean single loss expectance}
-#'   \item{sle_median}{median single loss expectance}
-#'   \item{sle_min}{minimum single loss expectance}
+#'   \item{loss_events_mean}{mean number of loss events}
+#'   \item{loss_events_min}{minimum number of loss events}
+#'   \item{loss_events_max}{maximum number of loss events}
+#'   \item{loss_events_median}{median number of loss events}
+#'   \item{ale_median}{median annual loss expected}
+#'   \item{ale_max}{maximum annual loss expected}
+#'   \item{ale_var}{value at risk, ale}
+#'   \item{sle_mean}{mean single loss expectancy}
+#'   \item{sle_median}{median single loss expectancy}
+#'   \item{sle_max}{maximum single loss expectancy}
+#'   \item{sle_min}{minimum single loss expectancy}
+#'   \item{mean_tc_exceedance}{mean threat capability exceedance}
+#'   \item{mean_diff_exceedance}{mean difficulty exceedance}
+#'   \item{mean_vuln}{mean vulnerability of the scenario}
+#'   \item{ale_var_zscore}{Z-score of ale VaR}
+#'   \item{outlier}{boolean - is this scenario an outlier}
 #' }
 "scenario_summary"
 
-#' Information security risk scenarios
+#' Quantified information security risk scenarios
 #'
 #' A dataset of quantified information security risk scenarios, with parameters
 #' describing the distribution of each input.
@@ -59,21 +86,38 @@
 #'   \item{tcomm}{full text name of threat community}
 #'   \item{domain_id}{domain abbreviation}
 #'   \item{controls}{comma separated list of control ids that apply to this scenario}
-#'   \item{lm_l}{loss magnitude - low}
-#'   \item{lm_ml}{loss magnitude - most likely}
-#'   \item{lm_h}{loss magnitude - high}
-#'   \item{lm_conf}{loss magnitude - confidence}
-#'   \item{tc_l}{threat capability - low}
-#'   \item{tc_ml}{threat capability - most likely}
-#'   \item{tc_h}{threat capability - high}
-#'   \item{tc_conf}{threat capability - confidence}
+#'   \item{diff_params}{nested dataframe of the controls and difficult parameters associated with the scenario}
 #'   \item{tef_l}{threat event frequency - low}
 #'   \item{tef_ml}{threat event frequency - most likely}
 #'   \item{tef_h}{threat event frequency - high}
 #'   \item{tef_conf}{threat event frequency - confidence}
+#'   \item{tc_l}{threat capability - low}
+#'   \item{tc_ml}{threat capability - most likely}
+#'   \item{tc_h}{threat capability - high}
+#'   \item{tc_conf}{threat capability - confidence}
+#'   \item{lm_l}{loss magnitude - low}
+#'   \item{lm_ml}{loss magnitude - most likely}
+#'   \item{lm_h}{loss magnitude - high}
+#'   \item{lm_conf}{loss magnitude - confidence}
 #' }
 "quantitative_scenarios"
 
+#' Qualitative information security risk scenarios
+#'
+#' A dataset of qualified information security risk scenarios.
+#'
+#' \describe{
+#'   \item{scenario_id}{id of the scenario, primary key}
+#'   \item{scenario}{full text description of the risk scenario}
+#'   \item{tcomm}{full text name of threat community}
+#'   \item{tef}{qualitative label of the frequency of threat events}
+#'   \item{tc}{qualitative label of the threat capability}
+#'   \item{lm}{qualitative label of the single loss magnitude}
+#'   \item{domain_id}{domain id to which the scenario applies}
+#'   \item{controls}{comma separate string of the controls for the scenario}
+#' }
+"qualitative_scenarios"
+
 #' Information security risk simulation results
 #'
 #' A dataset containing the full results of sample Monte Carlo
