@@ -13,4 +13,4 @@ NULL
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 ## technique from Jenny Bryan's googlesheet package
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
+utils::globalVariables(c("."))
